termparser_events library

Collection of events generated by the parser

Classes

ClipboardCopyEvent
Clipboard Copy Event
ColorQueryEvent
Represent a Color event response from OSC 11
ColorSchemeEvent
Color scheme preference event (response to CSI 996 n).
CursorPositionEvent
Represent a Cursor event.
EngineErrorEvent
Error event dispatched when the engine cannot parse a sequence. This is for structural errors (malformed sequences, invalid state transitions).
ErrorEvent
Parser/engine error events for malformed or invalid sequences.
Event
Base class for all events.
FocusEvent
Represent a Focus event.
InputEvent
User-generated input events (keyboard, mouse, paste).
InternalEvent
Internal parser events (no-op, unknown sequences).
KeyboardEnhancementFlagsEvent
Returns information terminal keyboard support
KeyCode
Represents a key pressed on the keyboard. This class is used for the legacy key events as well the enhanced key events. used on the Kitty protocol.
KeyEvent
Represent a Key event.
MouseButton
Represents a Mouse Event
MouseEvent
Represent a Mouse event.
NameAndVersionEvent
Terminal Name and Version
NoneEvent
Represent an empty event
PasteEvent
Paste Action Event
PrimaryDeviceAttributesEvent
Device Attribute
QueryBracketedPasteEvent
Query bracketed paste status (DECRPM response for mode 2004).
QuerySyncUpdateEvent
Query Sync update status
QueryTerminalWindowSizeEvent
Query Terminal size in pixels
QueryWindowResizeEvent
Query in-band window resize status (DECRPM response for mode 2048).
RawKeyEvent
Raw Key Event
ResponseEvent
Terminal responses to queries (cursor position, colors, device attributes).
SecondaryDeviceAttributesEvent
Secondary Device Attributes (DA2)
UnicodeCoreEvent
Unicode Core Event
WindowResizeEvent
Window resize event (in-band resize notification).

Enums

ClipboardSource
Clipboard Sources
ColorSchemeMode
Color scheme mode reported by terminal.
DECRPMStatus
DEC Report Mode status
DeviceAttributeParams
Device Attribute Params
DeviceAttributeType
Device Attribute Type
EngineErrorType
Type of engine error
KeyCodeKind
Discriminator for KeyCode variants
KeyCodeName
Enum for keys with names
KeyEventType
Enum for Key Events Types
MouseButtonAction
Represent a Mouse action
MouseButtonKind
Represent a Mouse button

Extension Types

KeyModifiers
An extension type representing key modifiers (Shift, Ctrl, Alt, etc.)