ColorSchemeEvent class final

Color scheme preference event (response to CSI 996 n).

Inheritance
Annotations
  • @immutable

Constructors

ColorSchemeEvent(int code)
Constructs a new instance of ColorSchemeEvent.

Properties

code int
The color scheme mode code reported by the terminal.
final
hashCode int
The hash code for this object.
no setteroverride
mode ColorSchemeMode
Get the color scheme mode.
latefinal
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override