ColorSchemeMode enum

Color scheme mode reported by terminal.

Inheritance
Available extensions

Values

unknown → const ColorSchemeMode

Unknown color scheme

const ColorSchemeMode(0)
dark → const ColorSchemeMode

Dark mode

const ColorSchemeMode(1)
light → const ColorSchemeMode

Light mode

const ColorSchemeMode(2)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
The numeric value for the color scheme.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ColorSchemeMode>
A constant List of the values in this enum, in order of their declaration.