CursorPositionEvent class final

Represent a Cursor event.

Inheritance
Annotations
  • @immutable

Constructors

CursorPositionEvent(int x, int y)
Constructs a new instance of CursorPositionEvent.
const

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
x → int
The x coordinate of the cursor event.
final
y → int
The y coordinate of the cursor event.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override