text property
The literal text this keystroke typed, as reported by the terminal's text-as-codepoints field. Null when the terminal did not report it.
Implementation
final String? text;
The literal text this keystroke typed, as reported by the terminal's text-as-codepoints field. Null when the terminal did not report it.
final String? text;