MouseButton class final

Represents a Mouse Event

Annotations
  • @immutable

Constructors

MouseButton(MouseButtonKind button, MouseButtonAction action)
Constructs a new instance of MouseButton.
const
MouseButton.down([MouseButtonKind? button])
Constructs a new instance of MouseButton with the given button and MouseButtonAction.down
factory
MouseButton.drag([MouseButtonKind? button])
Constructs a new instance of MouseButton with the given button and MouseButtonAction.drag
factory
MouseButton.moved([MouseButtonKind? button])
Constructs a new instance of MouseButton with MouseButtonAction.moved
factory
MouseButton.none()
Constructs a new instance of MouseButton with MouseButtonAction.none
factory
MouseButton.up([MouseButtonKind? button])
Constructs a new instance of MouseButton with the given button and MouseButtonAction.up
factory
MouseButton.wheelDown()
Constructs a new instance of MouseButton with MouseButtonAction.wheelDown
factory
MouseButton.wheelLeft()
Constructs a new instance of MouseButton with MouseButtonAction.wheelLeft
factory
MouseButton.wheelRight()
Constructs a new instance of MouseButton with MouseButtonAction.wheelRight
factory
MouseButton.wheelUp()
Constructs a new instance of MouseButton with MouseButtonAction.wheelUp
factory

Properties

action → MouseButtonAction
The kind of action that was performed
final
button → MouseButtonKind
Mouse Button that was pressed or released
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override