QuerySyncUpdateEvent class final

Inheritance
Annotations
  • @immutable

Constructors

QuerySyncUpdateEvent(int code)
Constructs a new instance of QuerySyncUpdateEvent.

Properties

code → int
The sync update status code reported by the terminal
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ DECRPMStatus
The sync update status
latefinal

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override