QueryTerminalWindowSizeEvent class final

Query Terminal size in pixels

Inheritance
Annotations
  • @immutable

Constructors

QueryTerminalWindowSizeEvent(int width, int height)
Constructs a new instance of QueryTerminalWindowSizeEvent.
const

Properties

hashCode int
The hash code for this object.
no setteroverride
height int
The terminal height
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width int
The terminal width
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override