QueryWindowResizeEvent class final

Query in-band window resize status (DECRPM response for mode 2048).

ref: https://gist.github.com/rockorager/e695fb2924d36b2bcf1fff4a3704bd83

Inheritance
Annotations
  • @immutable

Constructors

QueryWindowResizeEvent(int code)
Constructs a new instance of QueryWindowResizeEvent.

Properties

code int
The status code reported by the terminal.
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status DECRPMStatus
Get the DECRPM status.
latefinal

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override