Terminal responses to queries (cursor position, colors, device attributes).
Use ResponseEvent for type-safe filtering of terminal responses:
final responses = events.whereType<ResponseEvent>();
- Inheritance
- Implementers
- ClipboardCopyEvent
- ColorQueryEvent
- ColorSchemeEvent
- CursorPositionEvent
- FocusEvent
- KeyboardEnhancementFlagsEvent
- NameAndVersionEvent
- PrimaryDeviceAttributesEvent
- QueryBracketedPasteEvent
- QuerySyncUpdateEvent
- QueryTerminalWindowSizeEvent
- QueryWindowResizeEvent
- SecondaryDeviceAttributesEvent
- UnicodeCoreEvent
- WindowResizeEvent
Constructors
- ResponseEvent()
-
Constructor
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited