UnicodeCoreEvent class final

Unicode Core Event

Inheritance
Annotations
  • @immutable

Constructors

UnicodeCoreEvent(int code)
Constructs a new instance of UnicodeCoreEvent.

Properties

code → int
The Unicode Core status reported by the terminal
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ DECRPMStatus
Get the Unicode Core status
latefinal

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override