QueryBracketedPasteEvent class final
Query bracketed paste status (DECRPM response for mode 2004).
A Ps value of 0 (not recognized) or 4 (permanently disabled) indicates the terminal does not support bracketed paste.
- Inheritance
-
- Object
- Event
- ResponseEvent
- QueryBracketedPasteEvent
- Annotations
-
- @immutable
Constructors
- QueryBracketedPasteEvent(int code)
- Constructs a new instance of QueryBracketedPasteEvent.
Properties
- code → int
-
The status code reported by the terminal.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status ↔ DECRPMStatus
-
Get the DECRPM status.
latefinal
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override