SecondaryDeviceAttributesEvent class final
Secondary Device Attributes (DA2)
Reply to CSI > c, of the form CSI > Pp ; Pv ; Pc c. Identifies the
terminal type (Pp), firmware version (Pv) and cartridge/ROM (Pc).
Useful for emulator detection (xterm vs mintty vs iTerm2 vs kitty …).
- Inheritance
-
- Object
- Event
- ResponseEvent
- SecondaryDeviceAttributesEvent
- Annotations
-
- @immutable
Constructors
- SecondaryDeviceAttributesEvent(int type, int version, int cartridge)
-
Constructs a new instance of SecondaryDeviceAttributesEvent.
const
Properties
- cartridge → int
-
Cartridge / ROM number (Pc), usually 0.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → int
-
Terminal type identifier (Pp).
final
- version → int
-
Firmware / version (Pv).
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override