WindowResizeEvent class final
Window resize event (in-band resize notification).
Sent when terminal is resized and in-band resize reporting is enabled.
ref: https://gist.github.com/rockorager/e695fb2924d36b2bcf1fff4a3704bd83
- Inheritance
-
- Object
- Event
- ResponseEvent
- WindowResizeEvent
- Annotations
-
- @immutable
Constructors
- WindowResizeEvent(int heightChars, int widthChars, [int heightPixels = 0, int widthPixels = 0])
-
Constructs a new instance of WindowResizeEvent.
const
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- heightChars → int
-
Terminal height in characters.
final
- heightPixels → int
-
Terminal height in pixels (0 if unsupported).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- widthChars → int
-
Terminal width in characters.
final
- widthPixels → int
-
Terminal width in pixels (0 if unsupported).
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override